# Changelog

## 0.15.0 (2026-01-31)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/reminix-ai/reminix-python/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([e5ff5db](https://github.com/reminix-ai/reminix-python/commit/e5ff5db6098ec49d9d1eb64b3dc7af0158f26703))
* **api:** manual updates ([1fe2f99](https://github.com/reminix-ai/reminix-python/commit/1fe2f99145bdc421448aa1bf65a8b3bc7a2e950d))

## 0.14.0 (2026-01-31)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/reminix-ai/reminix-python/compare/v0.13.0...v0.14.0)

### Features

* **api:** api update ([3cd1084](https://github.com/reminix-ai/reminix-python/commit/3cd10840da485d4c2138a34da60b5527e8475a60))
* **api:** api update ([aaf4714](https://github.com/reminix-ai/reminix-python/commit/aaf471421a7aa8786cd4410ed37021a5867e8105))

## 0.13.0 (2026-01-31)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/reminix-ai/reminix-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** api update ([251185a](https://github.com/reminix-ai/reminix-python/commit/251185a2c00d3f2adf02203259e87ccca37d4261))
* **api:** api update ([265a3b7](https://github.com/reminix-ai/reminix-python/commit/265a3b7f9fa0f7161db7fbe870f710a546ca70b3))
* **api:** api update ([2729fd4](https://github.com/reminix-ai/reminix-python/commit/2729fd4264ab79fb7affaee4b938a92f635b70e2))
* **api:** api update ([8771121](https://github.com/reminix-ai/reminix-python/commit/87711212f13fbfce91a075f9cc8f5ef1ca9594f4))
* **api:** manual updates ([d1ce957](https://github.com/reminix-ai/reminix-python/commit/d1ce9574137cc4db15f33ba2b3bdd793486f7b35))
* **client:** add custom JSON encoder for extended type support ([4b64aa3](https://github.com/reminix-ai/reminix-python/commit/4b64aa3fa07462a6de9f2e0fcd3ecda3802b03ec))

## 0.12.0 (2026-01-29)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/reminix-ai/reminix-python/compare/v0.11.0...v0.12.0)

### Features

* **api:** api update ([6cdeb03](https://github.com/reminix-ai/reminix-python/commit/6cdeb03e1421f6f8e74fb295104965edb9ea43d9))
* **api:** manual updates ([6872b95](https://github.com/reminix-ai/reminix-python/commit/6872b95b62c7073a1314e5a84142bd7aeab93e67))

## 0.11.0 (2026-01-26)

Full Changelog: [v0.10.1...v0.11.0](https://github.com/reminix-ai/reminix-python/compare/v0.10.1...v0.11.0)

### Features

* **api:** api update ([9ee88a2](https://github.com/reminix-ai/reminix-python/commit/9ee88a25463ac09ebd1d36890928d8e9cad135b2))
* **api:** api update ([ac077b6](https://github.com/reminix-ai/reminix-python/commit/ac077b6e853daf9cf993a21d83bc1a9fc7f11ecf))
* **api:** api update ([95b3662](https://github.com/reminix-ai/reminix-python/commit/95b366218423c49afaf7ff86c4d877208edeb1de))
* **api:** api update ([afc3969](https://github.com/reminix-ai/reminix-python/commit/afc396954007220061cd453d27de4de3cb19993a))
* **api:** api update ([a775db1](https://github.com/reminix-ai/reminix-python/commit/a775db18d5c53ab8b9655ef118259fb197b41baf))
* **api:** api update ([f3e6d28](https://github.com/reminix-ai/reminix-python/commit/f3e6d28075e4dfab4b690ee72d7206537c4f5744))
* **api:** api update ([81af512](https://github.com/reminix-ai/reminix-python/commit/81af51200df3967e1aae12217361a54d98802484))
* **api:** api update ([21f7495](https://github.com/reminix-ai/reminix-python/commit/21f749501d631a4718b3f06089d4ce6841a9c48d))
* **api:** api update ([72eb66b](https://github.com/reminix-ai/reminix-python/commit/72eb66b103bd646a9b53fe3e3e16e4d5010e0063))
* **api:** api update ([d7b11ca](https://github.com/reminix-ai/reminix-python/commit/d7b11cae7522e24cad2108d520f5fd02788742ea))
* **api:** api update ([0b90c73](https://github.com/reminix-ai/reminix-python/commit/0b90c730a189a6ff3db7ffc00f0ce5308fbe7cdd))
* **api:** manual updates ([48bc291](https://github.com/reminix-ai/reminix-python/commit/48bc2914848d28a07cc0d778fbf083aec030fc7f))
* **api:** manual updates ([c5aeab3](https://github.com/reminix-ai/reminix-python/commit/c5aeab3dfb59fa5b08950d321d46b331e893d2c0))
* **api:** manual updates ([e08571f](https://github.com/reminix-ai/reminix-python/commit/e08571fa8355daadde67200b6a7658aa987c8c8d))
* **api:** manual updates ([3c5f19d](https://github.com/reminix-ai/reminix-python/commit/3c5f19d3223c0d3d1dba2c0d34b7b2f0675bdc82))
* **api:** manual updates ([ce0d26f](https://github.com/reminix-ai/reminix-python/commit/ce0d26ffd16a64e78caf1d1cbfa564df01059451))
* **api:** manual updates ([dbb4c22](https://github.com/reminix-ai/reminix-python/commit/dbb4c22df455742be95991be563ca7219574d1e8))
* **api:** manual updates ([7949800](https://github.com/reminix-ai/reminix-python/commit/79498008ac349b3be545a5a91e59e00b44083ea3))
* **api:** manual updates ([aade296](https://github.com/reminix-ai/reminix-python/commit/aade2964bdf332b172a6822de98f1e9b71927808))
* **api:** manual updates ([5c6f60d](https://github.com/reminix-ai/reminix-python/commit/5c6f60d8993ec7c669790f9545a4887c7f72e647))
* **api:** manual updates ([0488cb1](https://github.com/reminix-ai/reminix-python/commit/0488cb1297a6d10bf786818d7b20e5bd3d6695d7))
* **api:** manual updates ([ebd7e53](https://github.com/reminix-ai/reminix-python/commit/ebd7e53acbbb15cc52a1cb34bf8cf10c090d1948))


### Chores

* **ci:** upgrade `actions/github-script` ([8d20f19](https://github.com/reminix-ai/reminix-python/commit/8d20f1928817a47497d90508a4dd675844bae31f))

## 0.10.1 (2026-01-17)

Full Changelog: [v0.10.0...v0.10.1](https://github.com/reminix-ai/reminix-python/compare/v0.10.0...v0.10.1)

### Chores

* remove custom code ([79c273d](https://github.com/reminix-ai/reminix-python/commit/79c273d72db4818959779ab6b6ebbfc2cdc52d22))

## 0.10.0 (2026-01-17)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/reminix-ai/reminix-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([f764bc7](https://github.com/reminix-ai/reminix-python/commit/f764bc79fd4d7cde1bb3c15944da72d52a22fe02))
* **api:** api update ([6dbfa45](https://github.com/reminix-ai/reminix-python/commit/6dbfa45fb21c2e5504816ee838b98d67ae5d7dbb))
* **api:** manual updates ([a23228c](https://github.com/reminix-ai/reminix-python/commit/a23228cb66f67e5c0330fc30e7f96b1b4152f61e))
* **api:** manual updates ([4c38972](https://github.com/reminix-ai/reminix-python/commit/4c38972a8eaf4ff3ef208ef09f8fb571d41f7183))


### Chores

* remove custom code ([5ab7a67](https://github.com/reminix-ai/reminix-python/commit/5ab7a67e7bbc9787b950db1304a1fd1a7c60e38d))

## 0.9.0 (2026-01-17)

Full Changelog: [v0.8.4...v0.9.0](https://github.com/reminix-ai/reminix-python/compare/v0.8.4...v0.9.0)

### Features

* **api:** manual updates ([80a044a](https://github.com/reminix-ai/reminix-python/commit/80a044adc7397ff4838483286162b91648d1a085))

## 0.8.4 (2026-01-17)

Full Changelog: [v0.8.3...v0.8.4](https://github.com/reminix-ai/reminix-python/compare/v0.8.3...v0.8.4)

### Chores

* **internal:** update `actions/checkout` version ([b532210](https://github.com/reminix-ai/reminix-python/commit/b53221011c7a0d3e92ad22781f86a13b0be211b8))

## 0.8.3 (2026-01-16)

Full Changelog: [v0.8.2...v0.8.3](https://github.com/reminix-ai/reminix-python/compare/v0.8.2...v0.8.3)

### Features

* **api:** api update ([5048f43](https://github.com/reminix-ai/reminix-python/commit/5048f43b04992d99119c376bfaada081c48cbb85))
* **api:** manual updates ([d1569d9](https://github.com/reminix-ai/reminix-python/commit/d1569d9c9f384e9b63395dbfa0289ce7ad2ea792))
* **api:** manual updates ([d3d130d](https://github.com/reminix-ai/reminix-python/commit/d3d130d220094e70bc86f4eeeb2d92a7bae0aa25))
* **api:** manual updates ([441c124](https://github.com/reminix-ai/reminix-python/commit/441c12407bd14cb1fe0d2b6b1571fb7506038d39))
* **api:** manual updates ([9730384](https://github.com/reminix-ai/reminix-python/commit/973038498334fd4b49503049b5465af8f8c4486b))
* **api:** manual updates ([784708e](https://github.com/reminix-ai/reminix-python/commit/784708ef61ccfaec625574d473d7a58101a70464))
* **api:** manual updates ([8374976](https://github.com/reminix-ai/reminix-python/commit/837497673eccca998daa70b2828b2151daa3f137))
* **api:** manual updates ([d61bc7b](https://github.com/reminix-ai/reminix-python/commit/d61bc7bb592fbed2b41a1925bfeb8b1ad8a746ba))
* **client:** add support for binary request streaming ([fe247cc](https://github.com/reminix-ai/reminix-python/commit/fe247cce53d324fcedd1f5f5d2c28a52bd59a509))


### Chores

* remove custom code ([7699660](https://github.com/reminix-ai/reminix-python/commit/7699660edb5709313396025da780604abc4579da))

## 0.8.2 (2026-01-13)

Full Changelog: [v0.8.1...v0.8.2](https://github.com/reminix-ai/reminix-python/compare/v0.8.1...v0.8.2)

### Features

* **api:** api update ([21350dc](https://github.com/reminix-ai/reminix-python/commit/21350dcb9e608eb569855b54c8f5ea5e33b7b4ea))

## 0.8.1 (2026-01-13)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/reminix-ai/reminix-python/compare/v0.8.0...v0.8.1)

### Features

* add streaming support for chat and invoke methods ([7ddc828](https://github.com/reminix-ai/reminix-python/commit/7ddc8286b7c81a30289ef23dff210bfc4dbdf8b1))
* add streaming support for chat and invoke methods ([42ed11e](https://github.com/reminix-ai/reminix-python/commit/42ed11e9358c7353c0e33e0623a19b9b38c7b064))


### Bug Fixes

* add return type annotation to async example ([69fb5ff](https://github.com/reminix-ai/reminix-python/commit/69fb5ffa2134b9fa06707b9f7d7538d5a92ec1a2))
* remove duplicate imports from merge conflict ([19fe51b](https://github.com/reminix-ai/reminix-python/commit/19fe51b1436e633644ee4a2bc139668f9273387d))

## 0.8.0 (2026-01-13)

Full Changelog: [v0.0.1...v0.8.0](https://github.com/reminix-ai/reminix-python/compare/v0.0.1...v0.8.0)

### Chores

* update SDK settings ([9afabab](https://github.com/reminix-ai/reminix-python/commit/9afabab1c4874729441334cb49d162dfcd21a9e2))
* update SDK settings ([9450d09](https://github.com/reminix-ai/reminix-python/commit/9450d096f52ad8d13531c4242d29498bcc07fa62))
